==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/OnBalanceVolumeIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { OnBalanceVolumeIndicatorDescription } from "./OnBalanceVolumeIndicatorDescription";
/**
 * @hidden
 */
var OnBalanceVolumeIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OnBalanceVolumeIndicatorDescriptionMetadata, _super);
    function OnBalanceVolumeIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnBalanceVolumeIndicatorDescriptionMetadata.b = function (a) {
        if (OnBalanceVolumeIndicatorDescriptionMetadata.a == null) {
            OnBalanceVolumeIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OnBalanceVolumeIndicatorDescriptionMetadata.c(OnBalanceVolumeIndicatorDescriptionMetadata.a);
        }
        if (a.g(OnBalanceVolumeIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(OnBalanceVolumeIndicatorDescriptionMetadata.a);
    };
    OnBalanceVolumeIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    OnBalanceVolumeIndicatorDescriptionMetadata.d = function (a) {
        OnBalanceVolumeIndicatorDescriptionMetadata.b(a);
        a.u("OnBalanceVolumeIndicator", function () { return new OnBalanceVolumeIndicatorDescription(); });
        a.t("OnBalanceVolumeIndicator", OnBalanceVolumeIndicatorDescriptionMetadata.a);
    };
    OnBalanceVolumeIndicatorDescriptionMetadata.$t = markType(OnBalanceVolumeIndicatorDescriptionMetadata, 'OnBalanceVolumeIndicatorDescriptionMetadata');
    OnBalanceVolumeIndicatorDescriptionMetadata.a = null;
    return OnBalanceVolumeIndicatorDescriptionMetadata;
}(Base));
export { OnBalanceVolumeIndicatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/OnBalanceVolumeIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { OnBalanceVolumeIndicatorDescription } from "./OnBalanceVolumeIndicatorDescription";
/**
 * @hidden
 */
var OnBalanceVolumeIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(OnBalanceVolumeIndicatorDescriptionMetadata, _super);
    function OnBalanceVolumeIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnBalanceVolumeIndicatorDescriptionMetadata.b = function (a) {
        if (OnBalanceVolumeIndicatorDescriptionMetadata.a == null) {
            OnBalanceVolumeIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OnBalanceVolumeIndicatorDescriptionMetadata.c(OnBalanceVolumeIndicatorDescriptionMetadata.a);
        }
        if (a.j(OnBalanceVolumeIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(OnBalanceVolumeIndicatorDescriptionMetadata.a);
    };
    OnBalanceVolumeIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    OnBalanceVolumeIndicatorDescriptionMetadata.d = function (a) {
        OnBalanceVolumeIndicatorDescriptionMetadata.b(a);
        a.aa("OnBalanceVolumeIndicator", function () { return new OnBalanceVolumeIndicatorDescription(); });
        a.z("OnBalanceVolumeIndicator", OnBalanceVolumeIndicatorDescriptionMetadata.a);
    };
    OnBalanceVolumeIndicatorDescriptionMetadata.$t = markType(OnBalanceVolumeIndicatorDescriptionMetadata, 'OnBalanceVolumeIndicatorDescriptionMetadata');
    OnBalanceVolumeIndicatorDescriptionMetadata.a = null;
    return OnBalanceVolumeIndicatorDescriptionMetadata;
}(Base));
export { OnBalanceVolumeIndicatorDescriptionMetadata };
